DateTimeFormat class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Constants
-
dateAndTime
→ const DateTimeFormatter
-
Prints date and time (combines onlyDate and onlyTime).
-
none
→ const DateTimeFormatter
-
Omits the date and time completely.
-
onlyDate
→ const DateTimeFormatter
-
Prints only the date.
-
onlyTime
→ const DateTimeFormatter
-
Prints only the time.
-
onlyTimeAndSinceStart
→ const DateTimeFormatter
-
Prints only the time including the difference since
PrettyPrinter.startTime.