LogUtils class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isEnabled bool
no setter
level Level
no setter

Static Methods

configure({Level? level, LogOutput? output, bool? colors, bool? printEmojis, int? lineLength, int? methodCount, int? timedMethodCount, int? errorMethodCount, DateTime nowProvider()?, Map<Level, AnsiColor>? levelColors, Map<Level, String>? levelEmojis}) → void
Updates logger behavior without changing the static calling style.
d(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → void
Log a debug message.
disable() → void
Disable all logging
e(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → void
Log an error message.
enable() → void
Enable all logging
f(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → void
i(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → void
Log an info message.
log(Level level, dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → void
Logs a message at a specific level.
logTimeEvent(dynamic message, {String? key, bool printTime = false, Level level = Level.debug}) Duration
Records a time checkpoint and returns the elapsed duration.
resetAllTimes() → void
Clears all timing checkpoints.
resetConfiguration() → void
Restores the default logger configuration.
resetTime({String? key}) → void
Resets the last timestamp for a specific key.
setLevel(Level newLevel) → void
Change the log level
t(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → void
Log a verbose message.
w(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → void
Log a warning message.